@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from pypinyin import lazy_pinyin
 
 
@@ -6,7 +8,7 @@ class MappingFactory(object):
     匹配规则的生成工厂
     """
 
-    def get_specific_mapping(self, source, company) -> list:
+    def get_specific_mapping(self, source, company):
         """
         根据源和公司获取特定的匹配规则
 
@@ -17,9 +19,9 @@ class MappingFactory(object):
         """
         source = source.replace("&", "_")
         company = "".join(lazy_pinyin(company))
-        ipt_module = __import__(f'ph_data_clean.mapping.{source.lower()}_{company.lower()}')
+        ipt_module = __import__('ph_data_clean.mapping.%s_%s' % (source.lower(), company.lower()))
         mapping_pkg = getattr(ipt_module, 'mapping')
-        mapping_file = getattr(mapping_pkg, f'{source.lower()}_{company.lower()}')
+        mapping_file = getattr(mapping_pkg, '%s_%s' % (source.lower(), company.lower()))
         mapping_table = getattr(mapping_file, 'mapping')
         return mapping_table()
 
