@@ -15,9 +15,10 @@ from ph_max_auto.phcontext.phcontextfacade import PhContextFacade
               type=click.Choice(["create", "combine", "dag", "publish", "run", "submit", "status"]))
 @click.option("-p", "--path", prompt="Your config and python job file directory",
               help="The concert job you want the process.")
-@click.option("-c", "--context", default="{}")
+@click.option("-n", "--namespace", help="submit namespace", default="")
+@click.option("-c", "--context", help="submit context", default="{}")
 @click.argument('args', nargs=1, default="{}")
-def maxauto(runtime, cmd, path, context, args):
+def maxauto(runtime, cmd, path, namespace, context, args):
     """The Pharbers Max Job Command Line Interface (CLI)
         --runtime Args: \n
             python: This is to see \n
@@ -31,5 +32,5 @@ def maxauto(runtime, cmd, path, context, args):
         --path Args: \n
             the dictionary that specify the py and yaml file
     """
-    facade = PhContextFacade(runtime, cmd, path, context, args)
+    facade = PhContextFacade(runtime, cmd, path, namespace, context, args)
     click.get_current_context().exit(facade.execute())
